Documentation
¶
Overview ¶
Package dce implements dead code elimination for WGSL modules.
DCE works by: 1. Finding entry points (@vertex, @fragment, @compute functions) 2. Building a dependency graph of symbol references 3. Marking all symbols reachable from entry points as "live" 4. Filtering out declarations for non-live symbols during printing
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsDeclarationLive ¶
IsDeclarationLive returns true if the declaration should be included in output.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.